//
// QPerforce is a gui interface to the perforce revision control
// system. It is based on the qt library, and should be easily portable
// across any platform that has this toolkit available.
// 
// Copyright (C) 2002 Jacob Gladish
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
#include "UserMenu.h"
#include "P4Process.h"
#include "todo.h"
#include "User.h"
#include "WidgetId.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

UserMenu::UserMenu( QWidget* parent, const char* name ) : 
  QPopupMenu( parent, name ), 
  IUpdateable()
{
  insertItem( "New..", this, SLOT(slotNew()) );
  insertItem( "Edit...", this, SLOT(slotEdit()) );
  insertItem( "Describe...", this, SLOT(slotDescribe()) );
  insertItem( "Delete", this, SLOT(slotDelete()) );

  insertSeparator();

  insertItem( "Set Password for...", this, SLOT(slotSetPasswordFor()) );
  insertItem( "Switch to User", this, SLOT(slotSwitchToUser()) );
  insertItem( "Set Default User", this, SLOT(slotSetDefaultUser()) );

  insertSeparator();

  insertItem( "View Changes by", this, SLOT(slotViewChangesBy()) );
  insertItem( "View Users", this, SLOT(slotViewUsers()) );
}

UserMenu::~UserMenu()
{

}

void UserMenu::slotNew()
{
  TODO();
}



void UserMenu::slotEdit()
{
  TODO();
}

void UserMenu::slotDescribe()
{
  TODO();
}


void UserMenu::slotDelete()
{
  TODO();
}



void UserMenu::slotSetPasswordFor()
{
  TODO();
}

void UserMenu::slotSwitchToUser()
{
  TODO();
}

void UserMenu::slotSetDefaultUser()
{
  TODO();
}

void UserMenu::slotViewChangesBy()
{
  TODO();
}

void UserMenu::setListView( UserTable* view )
{
  ASSERT( view != NULL );
  _myView = view;
}


void UserMenu::slotViewUsers()
{  
  // if the users list is empty, and wants to be refreshed
  updateCacheIfNecessary();
  
  _myView->clear();

  for (Perforce::User* u = _users.first(); u != NULL; u = _users.next()) {
    // do something with these guys.
    ASSERT( u != NULL ); 
    ASSERT( _myView != NULL );

    _myView->addUser( u );
    
    // qDebug( "%s %s %s %s", 
    //   u->getFullName().latin1(),
    //   u->getUserName().latin1(),      
    //   u->getEmail().latin1(),
    //   u->getLastAccessed().toString().latin1() );        
  }

  // signal that we're showing the users
  emit showUsers( USERS_TABLE );
  
}


void UserMenu::updateCache()
{
  qDebug( "Updating user cache" );
  P4Process p4;
  _users = p4.getUsers();
}